==> s-loc-instance-0.0.2.tgz: package/launch.js <==

let Run = require('./scripts/run');
module.exports = {
    Setup : function (worker, processes, failed) {
        let cluster = require('cluster');
        if (cluster.isMaster) {
            Run().then(function () {
                let cpus = require('os').cpus().length;
                console.log('Forking S_Loc_Instance Version', require('./package.json').version);
                for (let i = 0; i < cpus; i += 1) {
                    cluster.fork();
                    if (worker) {
                        worker.on('message', worker);
                    }
                }
            }).catch(failed);
        } else {
            if (processes) {
                processes(cluster.worker.id)
            }
        }
    },
    InstanceItem: require('./lib/index').InstanceItem,
    None: require('./lib/index').None,
    Dynamo: require('./lib/index').Dynamo,
};

/*async function RunHook() {

    try {
        await InstanceHook.parse();
        await LS((!InstanceHook.Instance) ? InstanceHook : InstanceHook.Instance)
        await InstanceHook.updateRootDBWithInstanceParams();
        //let done = await InstanceHook.parseHook();
    } catch (e) {
        throw e;
    }
}*/
/*
async function AlertDispatcher(instance) {
    let axios = require('axios');
    let S3Wrapper = require('./S3Wrapper');
    let region = process.env['region'];
    let instanceid = process.env['instance_id'];
    if (!region || !instanceid) throw "Missing Basic Information";
    instanceid = instanceid.replace('-',"_");
    try {
        let Machine = new S3Wrapper(null, {
            Bucket: 'locality-pos',
            Key: 'region-details.json'});
        let MachineJSON = await Machine.get();
        let Wrap = new S3Wrapper(null, {
            Bucket: MachineJSON.region_name+'-dispatcher-metadata',
            Key: MachineJSON.region_name+'-dispatcher-notifiers-creds.json'});
        let json = await Wrap.get();
        if (!json.path) throw "Missing Path";
        if (!json.authorization) throw "Missing Auth";
        if (!json.accessor) throw "Missing Accessor";
        let locid = await GetLocID(instanceid);
        let request = await axios.post(json.path, {
                account: MachineJSON.region_name,
                authorization: json.authorization,
                message: "instance="+process.env['instance_id']+"&action=launched&port=3000&location="+locid
            }, {
                headers: {
                    'x-api-key': json.accessor,
                    "Content-Type":"application/json"
                }});
        if (!request.data) throw "Error : "+"Request failed";
        console.log(request.data.error);
        console.log(request.data.body);
        let code = request.data.body.statusCode;
        if (code !== 200) throw "Error : "+request.data.body.message;
        return Promise.resolve();
    } catch(e) {
        throw e;
    }
    function GetLocID(insid) {
        let AWS = require('aws-sdk');
        let dynamo = new AWS.DynamoDB({apiVersion: "2012-08-10", region: region});
        return new Promise(function (result) {
            dynamo.getItem({
                TableName: "location_information",
                Key: {
                    "instance_id": {
                        S: insid
                    }
                }
            }, function (err, data) {
                console.log('err', err);
                if (err) return result(Promise.reject(err));
                if (!data.Item) return result(Promise.reject("Invalid Item Found For Location"));
                if (!data.Item.location_id) return result(Promise.reject("Invalid Item Found - No Location"));
                return result(data.Item.location_id.S);
            })
        })
    }
}*/

==> s-loc-instance-0.1.3.tgz: package/launch.js <==

let Run = require('./scripts/run');
module.exports = {
    Setup : function (worker, processes, failed) {
        let cluster = require('cluster');
        if (cluster.isMaster) {
            Run().then(function () {
                let cpus = require('os').cpus().length;
                console.log('Forking S_Loc_Instance Version', require('./package.json').version);
                for (let i = 0; i < cpus; i += 1) {
                    cluster.fork();
                    if (worker) {
                        worker.on('message', function (message) {
                            worker(message);
                        });
                    }
                }
            }).catch(failed);
        } else {
            if (processes) {
                processes(cluster.worker.id)
            }
        }
    },
    InstanceItem: require('./lib/index').InstanceItem,
    None: require('./lib/index').None,
    Dynamo: require('./lib/index').Dynamo,
};

/*async function RunHook() {

    try {
        await InstanceHook.parse();
        await LS((!InstanceHook.Instance) ? InstanceHook : InstanceHook.Instance)
        await InstanceHook.updateRootDBWithInstanceParams();
        //let done = await InstanceHook.parseHook();
    } catch (e) {
        throw e;
    }
}*/
/*
async function AlertDispatcher(instance) {
    let axios = require('axios');
    let S3Wrapper = require('./S3Wrapper');
    let region = process.env['region'];
    let instanceid = process.env['instance_id'];
    if (!region || !instanceid) throw "Missing Basic Information";
    instanceid = instanceid.replace('-',"_");
    try {
        let Machine = new S3Wrapper(null, {
            Bucket: 'locality-pos',
            Key: 'region-details.json'});
        let MachineJSON = await Machine.get();
        let Wrap = new S3Wrapper(null, {
            Bucket: MachineJSON.region_name+'-dispatcher-metadata',
            Key: MachineJSON.region_name+'-dispatcher-notifiers-creds.json'});
        let json = await Wrap.get();
        if (!json.path) throw "Missing Path";
        if (!json.authorization) throw "Missing Auth";
        if (!json.accessor) throw "Missing Accessor";
        let locid = await GetLocID(instanceid);
        let request = await axios.post(json.path, {
                account: MachineJSON.region_name,
                authorization: json.authorization,
                message: "instance="+process.env['instance_id']+"&action=launched&port=3000&location="+locid
            }, {
                headers: {
                    'x-api-key': json.accessor,
                    "Content-Type":"application/json"
                }});
        if (!request.data) throw "Error : "+"Request failed";
        console.log(request.data.error);
        console.log(request.data.body);
        let code = request.data.body.statusCode;
        if (code !== 200) throw "Error : "+request.data.body.message;
        return Promise.resolve();
    } catch(e) {
        throw e;
    }
    function GetLocID(insid) {
        let AWS = require('aws-sdk');
        let dynamo = new AWS.DynamoDB({apiVersion: "2012-08-10", region: region});
        return new Promise(function (result) {
            dynamo.getItem({
                TableName: "location_information",
                Key: {
                    "instance_id": {
                        S: insid
                    }
                }
            }, function (err, data) {
                console.log('err', err);
                if (err) return result(Promise.reject(err));
                if (!data.Item) return result(Promise.reject("Invalid Item Found For Location"));
                if (!data.Item.location_id) return result(Promise.reject("Invalid Item Found - No Location"));
                return result(data.Item.location_id.S);
            })
        })
    }
}*/
